#! /usr/bin/env tclsh

lappend auto_path [file join [file dirname [info script]] .. lib]

		package require teapotclient

                puts "The following extensions are available:"
                foreach {extension extensioninfo} [::teapotclient::get_extensions \
                                                   teapot.activestate.com \
                                                   {*} {*}] {
                        puts "  $extension [join $extensioninfo {, }]"
                }
